@@ -185,7 +185,7 @@ gssdp_net_mac_lookup (GSSDPNetworkDevice *device, const char *ip_address)
 }
 
 gboolean
-gssdp_net_get_host_ip (GSSDPNetworkDevice *device)
+gssdp_net_get_host_ip (GSSDPNetworkDevice *device, GError **error)
 {
         GList *up_ifaces = NULL, *ifaceptr = NULL;
         ULONG flags = GAA_FLAG_INCLUDE_PREFIX |
